#!/usr/bin/env python

# ======================================================================
# Copyright (C) 2005-2006  Robert Muth
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, version 2 of the License.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# This software has been successfully tested with python 2.1
#
# For more information, invoke as "freedbtool.py -h"
#
# $Id: gen_toc.py 437 2007-11-05 05:25:20Z muth $
#
# ======================================================================

"""
gen_toc.py - a python program for generating a fake toc files
based on the files in the current directory
for the freedb.org database
"""

import glob
import os
import sys
import re
import getopt

# ======================================================================
def generate_toc(num_tracks, artist, album):

    print "# CD database file"
    print "# Copyright (C) 2005"
    print "#"
    print "# Track frame offsets:"

    for i in range(num_tracks):
        print "#    %d" % (100 * i)

    print "# Disc length: 666"
    print "#"
    print "# Revision: 1"
    print "# Processed by:"
    print "# Submitted via:"
    print "#"

    print "DISCID=cafecafe"

    print "DTITLE=%s / %s" % (artist, album)

    album = album.replace("_", " ")
    for i in range(num_tracks):
        print "TTITLE%d=%s track %d" % (i, album, i)
    print "EXTD="

    for i in range(num_tracks):
        print "EXTT%d=" % i

    print "PLAYORDER="
    return
# ======================================================================
_RE_TRACK = re.compile("^(?:track)?(\d\d)")
# ======================================================================
def main(argv):
    assert(len(argv) == 1)
    fullpath = os.path.abspath(argv[0])
    components = fullpath.split("/")
#    print components
    name = components.pop(-1)
    if len(name) < 6:
        name = components.pop(-1) + " " + name

#    print name
    artist, album = name.split("-")
    filelist = []
    for ext in ["mpc", "MPC", "mp3", "MP3", "flac", "FLAC"]:
        filelist  += glob.glob(fullpath + "/*." + ext)
    max = 0
    for f in filelist:
        components = f.split("/")
        match = _RE_TRACK.search(components[-1])
        if match:
            t = int(match.group(1))
            if t > max: max = t
    generate_toc(max, artist, album)
    return 0
# ======================================================================
if __name__ == "__main__":
    sys.exit(main(sys.argv[1:]))


